// --------------------------------------------------------------------
// Author  : mashimonator
// Create  : 2009/01/17
// Update  : 2009/01/26
// Description : 擬似的にIEのruby要素を再現する
// --------------------------------------------------------------------

var ruby = {

	//-----------------------------------------
	// 設定値
	//-----------------------------------------
	conf : {

		rubyClassName : 'ruby',       // 対象とするクラス名
		rubyElemName : 'span',        // 対象とする要素名
		rp : ['（','）'],             // ルビの内容を囲む記号
		currentVal : 0,               // 初期表示設定(0:表示されて開始/1:非表示で開始)
		btnElemName : 'input',        // ruby表示切り替えボタンの要素名(input,imgなど)
		btnClassName : 'rubyButton',  // ruby表示切り替えボタンに付加するクラス名
		btnAttribute : 'value',       // 値を変更する属性名(value,srcなど)
		btnAtrDispValue : '解除',     // ruby表示時の値
		btnAtrHideValue : '表示'      // ruby非表示時の値

	},

	//-----------------------------------------
	// Main処理(rubyの表示切り替え)
	//-----------------------------------------
	change : function() {

		var cb = new checkbrowser();
		var elements = ruby.getTargetElements(ruby.conf.rubyElemName, ruby.conf.rubyClassName, ruby.conf.currentVal);
		var div = document.getElementById('ruby');

		// 初期表示設定によって切り替え
		if (ruby.conf.currentVal == 0) {
			ruby.disp(elements, ruby.conf.rubyClassName, ruby.conf.rp);
			ruby.conf.currentVal = 1;
			if (div) {
				div.className = 'rubyStyle';
			}
			ruby.changeButton(ruby.conf.btnElemName, ruby.conf.btnClassName, ruby.conf.btnAttribute, ruby.conf.btnAtrDispValue);
		} else {
			ruby.hide(elements, ruby.conf.rubyClassName, ruby.conf.rp, cb.browserSName);
			ruby.conf.currentVal = 0;
			if (div) {
				div.className = 'normalStyle';
			}
			ruby.changeButton(ruby.conf.btnElemName, ruby.conf.btnClassName, ruby.conf.btnAttribute, ruby.conf.btnAtrHideValue);
		}

	},

	//-----------------------------------------
	// 表示
	//-----------------------------------------
	disp : function(elements, cls, rp) {
		
		var rubyLengthClassName = Array('one','two','three','four','five');
		
		for (var i = 0; i < elements.length; i++) {
			
			var element = elements[i];
			var str = element.firstChild.nodeValue;
			
			if (str) {
				var ruby = Array(
					'<span class=\"rb\">',
					str.substr(0, str.indexOf(rp[0])),
					'</span><span class=\"rp\">' + rp[0] + '</span><span class=\"rt\">',
					str.substr(str.indexOf(rp[0]) + 1, str.length - str.indexOf(rp[0]) - 2),
					'</span><span class=\"rp\">' + rp[1] + '</span>'
				);
				element.innerHTML = ruby.join('');
				element.className = cls + ' ' + rubyLengthClassName[str.indexOf(rp[0]) - 1];
			}
			
		}

	},

	//-----------------------------------------
	// 非表示
	//-----------------------------------------
	hide : function(elements, cls, rp, browser) {

		for (var i = 0; i < elements.length; i++) {
			
			var element = elements[i];
			var str = element.innerHTML;
			
			if (browser == "IE") {
				// for IE
				str = str.replace(/> /g, '>');
				str = str.replace(/<SPAN class=rb>/g, '');
				str = str.replace(/<\/SPAN><SPAN class=rp>/g, '');
				str = str.replace(/<\/SPAN><SPAN class=rt>/g, '');
				str = str.replace(/<\/SPAN>/g, '');
			} else {
				str = str.replace(/[\n\r]/g, '');
				str = str.replace('<span class=\"rb\">', '', 'i');
				str = str.replace('</span><span class=\"rp\">' + rp[0] + '</span><span class=\"rt\">', rp[0], 'i');
				str = str.replace('</span><span class=\"rp\">' + rp[1] + '</span>', rp[1], 'i');
			}
			
			element.innerHTML = str;
			element.className = cls;
			
		}

	},

	//-----------------------------------------
	// ターゲットタグを取得する
	//-----------------------------------------
	getTargetElements : function(tag, cls, mode) {

		var elements = new Array();
		var targetElements = document.getElementsByTagName(tag);

		if (mode == 0) {
			
			// 表示用
			for (var i = 0; i < targetElements.length; i++) {
				if (targetElements[i].className == cls) {
					elements[elements.length] = targetElements[i];
				}
			}
			
		} else {
			
			// 非表示用
			for (var i = 0; i < targetElements.length; i++) {
				if (targetElements[i].className.match(cls)) {
					elements[elements.length] = targetElements[i];
				}
			}
			
		}

		return elements;

	},

	//-----------------------------------------
	// ボタンの表示切り替え
	//-----------------------------------------
	changeButton : function(tag, cls, attr, val) {

		var elements = new Array();
		var targetElements = document.getElementsByTagName(tag);

		for (var i = 0; i < targetElements.length; i++) {
			if (targetElements[i].className == cls) {
				targetElements[i].setAttribute(attr, val);
			}
		}

	},

	//-----------------------------------------
	// Loadイベントに追加
	//-----------------------------------------
	addLoadEvent : function() {
		try {
			window.addEventListener('load', this.change, false);
		} catch (e) {
			window.attachEvent('onload', this.change);
		}
	}

}

ruby.addLoadEvent();

var checkbrowser = function() {

	// ブラウザ
	this.browserName = '';     // [String]  ブラウザ名
	this.browserSName = '';    // [String]  ブラウザ名(略)
	this.browserMVersion = 0;  // [Int]     ブラウザメジャーバージョン
	this.browserVersion = 0;   // [Float]   ブラウザバージョン
	// ------
	this.ie = false;           // [Boolean] InternetExplorerである場合はtrue
	this.macie = false;        // [Boolean] MacIEであれば true
	this.firefox = false;      // [Boolean] Firefoxであれば true
	this.safari = false;       // [Boolean] Safariであれば true
	this.opera = false;        // [Boolean] Operaであれば true
	this.netscape = false;     // [Boolean] Netscapeであれば true
	this.gchrome = false;      // [Boolean] Google Chromeであれば true

	// エンジン
	this.engineName = '';      // [String]  エンジン名
	this.engineVersion = 0;    // [Float]   エンジンバージョン
	// ------
	this.webkit = false;       // [Boolean] Webkitエンジンを使用していれば true
	this.gecko = false;        // [Boolean] Geckoエンジンを使用していれば true
	this.presto = false;       // [Boolean] Prestoエンジンを使用していれば true
	this.trident = false;      // [Boolean] Tridentエンジンを使用していれば true
	this.tasman = false;       // [Boolean] Tasmanエンジンを使用していれば true

	var constBrowser = new Array('MSIE','Firefox','Opera','Safari','Chrome','Netscape');
	var constSBrowser = new Array('IE','FF','OP','SF','GC','NS');
	var constEngine = new Array('Gecko','WebKit','Presto','Trident','Tasman');

	var uaString = navigator.userAgent;

	var i;

	// ブラウザ取得
	for (i=0; i<constBrowser.length; i++) {
		if ( uaString.match(constBrowser[i]) ) {
			if ( constBrowser[i] == 'MSIE' ) {
				if ( uaString.match('Windows NT') ) {
					this.ie = true;
					this.trident = true;
					this.engineName = 'Trident';
				} else {
					this.macie = true;
					this.tasman = true;
					this.engineName = 'Tasman';
				}
				this.browserName = 'Internet Explorer';
				this.browserSName = constSBrowser[i];
				break;
			} else if ( constBrowser[i] == 'Safari' ) {
				if ( uaString.match('Chrome') ) {
					this.browserName = 'Google Chrome';
					this.browserSName = 'GC';
					this.gchrome = true;
				} else {
					this.browserName = constBrowser[i];
					this.browserSName = constSBrowser[i];
					this.safari = true;
				}
				break;
			} else if ( constBrowser[i] == 'Chrome' ) {
				this.browserName = 'Google Chrome';
				this.browserSName = constSBrowser[i];
				this.gchrome = true;
				break;
			} else  {
				if ( constBrowser[i] == 'Firefox' ) {
					this.firefox = true;
				} else if ( constBrowser[i] == 'Opera' ) {
					this.opera = true;
				} else if ( constBrowser[i] == 'Netscape' ) {
					this.netscape = true;
				}
				this.browserName = constBrowser[i];
				this.browserSName = constSBrowser[i];
				break;
			}
		}
	}

	// ブラウザバージョン取得
	var str = '';
	uaString = uaString + ' ';
	if ( this.browserSName == 'IE' ) {
		str = uaString.substring(uaString.indexOf(this.browserSName), uaString.length);
		str = str.substring(0, str.indexOf(';'));
		str = str.substring(str.indexOf(' ') + 1, str.length);
	} else if ( this.browserSName == 'SF' ) {
		str = uaString.substring(uaString.indexOf('Version'), uaString.length);
		str = str.substring(0, str.indexOf(' '));
		str = str.substring(str.indexOf('/') + 1, str.length);
	} else if ( this.browserSName == 'GC' ) {
		str = uaString.substring(uaString.indexOf('Chrome'), uaString.length);
		str = str.substring(0, str.indexOf(' '));
		str = str.substring(str.indexOf('/') + 1, str.length);
	} else {
		str = uaString.substring(uaString.indexOf(this.browserName), uaString.length);
		str = str.substring(0, str.indexOf(' '));
		str = str.substring(str.indexOf('/') + 1, str.length);
	}
	var result = new Array();
	var ary = str.split('.');
	for (i=0; i<ary.length; i++) {
		if (i == 0) {
			result[0] = ary[i];
			result[1] = ary[i];
		} else if (i == 1) {
			result[1] = result[1] + '.' + ary[i];
			break;
		}
	}
	this.browserMVersion = parseInt(result[0]);
	this.browserVersion =  parseFloat(result[1]);


	// エンジン取得
	if ( this.browserSName != 'IE' ) {
		for (i=0; i<constEngine.length; i++) {
			if ( uaString.match(constEngine[i]) ) {
				if ( constEngine[i] == 'Gecko' ) {
					if ( uaString.match('WebKit') ) {
						this.engineName = 'WebKit';
						this.webkit = true;
					} else {
						this.engineName = constEngine[i];
						this.gecko = true;
					}
				} else {
					if ( constEngine[i] == 'WebKit' ) {
						this.webkit = true;
					} else if ( constEngine[i] == 'Presto' ) {
						this.presto = true;
					}
					this.engineName = constEngine[i];
				}
				break;
			}
		}
	}

	// エンジンバージョン取得
	str = '';
	if ( this.browserSName != 'IE' ) {

		uaString = uaString + ' ';
		if ( this.engineName == 'Gecko' ) {
			str = uaString.substring(uaString.indexOf('rv:'), uaString.length);
			str = str.substring(0, str.indexOf(')'));
			str = str.replace(/^rv:/,'');
		} else {
			str = uaString.substring(uaString.indexOf(this.engineName), uaString.length);
			str = str.substring(0, str.indexOf(' '));
			str = str.substring(str.indexOf('/') + 1, str.length);
		}

		result = new Array();
		ary = str.split('.');
		for (i=0; i<ary.length; i++) {
			if (i == 0) {
				result[0] = ary[i];
			} else if (i == 1) {
				result[0] = result[0] + '.' + ary[i];
				break;
			}
		}

		this.engineVersion =  parseFloat(result[0]);

	} else if ( uaString.match('Trident') ) {

		str = uaString.substring(uaString.indexOf(this.engineName), uaString.length);
		str = str.substring(0, str.indexOf(';'));
		str = str.substring(str.indexOf('/') + 1, str.length);

		result = new Array();
		ary = str.split('.');
		for (i=0; i<ary.length; i++) {
			if (i == 0) {
				result[0] = ary[i];
			} else if (i == 1) {
				result[0] = result[0] + '.' + ary[i];
				break;
			}
		}

		this.engineVersion =  parseFloat(result[0]);

	}

}